/**
	$Id$

	Copyright (C) 2016 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.startpage;

import net.sf.basedb.clients.web.extensions.AbstractJspActionFactory;
import net.sf.basedb.util.extensions.InvokationContext;
import net.sf.basedb.util.extensions.xml.PathConverter;
import net.sf.basedb.util.extensions.xml.PathSetter;
import net.sf.basedb.util.extensions.xml.VariableSetter;

/**
	A simple start page action factory. Use the 
	parameters to set name, description and URL. The
	ID is autoamtically set to the ID of the extension.
	The {@link #setUrl(String)} method supports path 
	variables. See {@link PathConverter}.
	
	@author nicklas
	@since 3.8
*/
public class FixedStartPageFactory
	extends AbstractJspActionFactory<StartPageAction>
	implements StartPageAction
{
	
	private StartPageAction[] actions;
	
	private String id;
	
	private String name;
	
	private String description;
	
	private String url;
	
	/**
		Create a new factory instance.
	*/
	public FixedStartPageFactory()
	{
		actions = new StartPageAction[] { this };
	}
	
	/*
		From the ActionFactory interface
		--------------------------------
	*/
	/**
		@return Always an array with a single element
	*/
	@Override
	public StartPageAction[] getActions(InvokationContext<? super StartPageAction> context)
	{
		if (id == null) id = context.getExtension().getId();
		return actions;
	}
	// ----------------------------------

	/*
		From the StartPageAction interface
		----------------------------------
	*/
	@Override
	public String getId() 
	{
		return id;
	}
	
	@Override
	public String getName()
	{
		return name;
	}

	@Override
	public String getDescription()
	{
		return description;
	}
	
	@Override
	public String getUrl()
	{
		return url;
	}
	// ----------------------------------
	
	public void setName(String name)
	{
		this.name = name;
	}

	public void setDescription(String description)
	{
		this.description = description;
	}
	
	@VariableSetter
	@PathSetter
	public void setUrl(String url)
	{
		this.url = url;
	}

}
