package net.sf.basedb.clients.web.util;

import net.sf.basedb.core.snapshot.AnnotationLoaderUtil;
import net.sf.basedb.core.snapshot.AnnotationSnapshot;
import net.sf.basedb.util.filter.Filter;

/**
	Helper class for finding out information about about
	annotation snapshots returned by 
	{@link AnnotationLoaderUtil#findAll(net.sf.basedb.core.snapshot.AnnotationSetSnapshot, Filter)}
	method.
	
	This class will not filter the results, but only set flags 
	if it finds a project-specific annotation that is overriding
	a default value.
	
	@author nicklas
	@since 3.11
*/
public class ProjectSpecificInfoFilter 
	implements Filter<AnnotationSnapshot>
{

	private boolean projectSpecific;
	private boolean override;
	
	public ProjectSpecificInfoFilter()
	{}

	/**
		Evaluate the annotation snapshot and update the
		flags if the snapshot is a project-specific annotation
		and overrides a default value.
	 */
	@Override
	public boolean evaluate(AnnotationSnapshot snapshot)
	{
		projectSpecific |= snapshot.getProjectId() != 0;
		override |= snapshot.getOverrideId() != 0;
		return true;
	}

	/**
		Reset the flags to false.
		@return 'this' to allow for method chaining
	*/
	public ProjectSpecificInfoFilter reset()
	{
		projectSpecific = false;
		override = false;
		return this;
	}
	
	/**
		Check if the project-specific flag is set.
	*/
	public boolean hasProjectSpecificAnnotation()
	{
		return projectSpecific;
	}

	/**
		Check if the override flag is set.
	*/
	public boolean overridesDefaultAnnotation()
	{
		return override;
	}
	
}
