/*
  $Id: PlatformFileTypeData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This class hols information about which file types
	are used on which experimental platforms and variants.
	
	@author Nicklas
	@version 2.5
	@see net.sf.basedb.core.PlatformFileType
	@see <a href="../../../../../../html/developer/api/data_api.platforms.html">Developer documentation: Experimental platforms and item subtypes</a>
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (fr, 21 okt 2011) $
	@hibernate.class table="`PlatformFileTypes`" lazy="true"
*/
public class PlatformFileTypeData
	extends BasicData
{
	
	private DataFileTypeData fileType;
	/**
		Get the file type.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`datafiletype_id`" not-null="true"
	*/
	public DataFileTypeData getDataFileType()
	{
		return fileType;
	}
	public void setDataFileType(DataFileTypeData fileType)
	{
		this.fileType = fileType;
	}
	
	private PlatformData platform;
	/**
		Get the platform.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`platform_id`" not-null="true"
	*/
	public PlatformData getPlatform()
	{
		return platform;
	}
	public void setPlatform(PlatformData platform)
	{
		this.platform = platform;
	}
	
	private PlatformVariantData variant;
	/**
		Get the platform variant or null.
		@hibernate.many-to-one outer-join="false" update="false"
		@hibernate.column name="`variant_id`" not-null="false"
	*/
	public PlatformVariantData getVariant()
	{
		return variant;
	}
	public void setVariant(PlatformVariantData variant)
	{
		this.variant = variant;
	}
	
	private boolean required;
	/**
		If a file of this type is required or not.
		@hibernate.property column="`required`" type="boolean" not-null="true"
	*/
	public boolean isRequired()
	{
		return required;
	}
	public void setRequired(boolean required)
	{
		this.required = required;
	}

	private boolean multiple;
	/**
		If multiple files of this type are allowed in a file set or not.
		@hibernate.property column="`allow_multiple`" type="boolean" not-null="true"
	*/
	public boolean getAllowMultiple()
	{
		return multiple;
	}
	public void setAllowMultiple(boolean multiple)
	{
		this.multiple = multiple;
	}

	
}
