/**
	$Id$

	Copyright (C) 2015 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.listable;

import java.util.Set;

import net.sf.basedb.core.Item;

/**
	Implementations are responsible for transforming a set of source item
	ID:s into a set of related target item ID:s. The rules for transforming
	is up to each implementation.
	
	@author Nicklas
	@since 3.5
*/
public interface SourceItemTransformer 
{

	/**
		Get the item type of the source items.
	*/
	public Item getSourceItemType();
	
	
	/**
		Get the item type of the target items.
	*/
	public Item getTargetItemType();
	
	/**
		Transform the given set of source item ID:s into a set of target item ID:s
	*/
	public Set<Integer> transform(TransformContext context, Set<Integer> source);
	
}
